//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine science & computing) 
// December 2001
//
// $Id: crabephemeris.cc,v 1.1 2001/12/20 13:09:06 gvacanti Exp $
//
// Interpolates the Crab Pulsar radio ephemeris published by Jodrell
// Bank. It expects the following items as input:
//
//  MJD from ephemeris
//  frequency (Hz)
//  frequency dot (Hz/s) in units of e-15
//  date to interpolate to (yyy-mm-ddThh:mm:ss)
//
// Output:
//
//  Period, period dot, frequency twodot at the requested time.
//
// The algorithm follows what is described in the Jodrell Bank
// documentation.

#include<iostream>
#include<cmath>
#include<STime.h>

int main() {
  double f = 1.;
  double fdot = 0.;
  unsigned long mjd = 0;

  std::cout << "Enter MJD frequency and frequencydotxe-15 from the ephemeris:"
	    << std::endl;
  std::cin >> mjd >> f >> fdot;
  fdot *= 1e-15;
  STime jbdate(mjd);

  std::string datestr("now");
  std::cout << "Enter the date to interpolate to: " << std::endl;
  std::cin >> datestr;

  STime date(datestr);

  // This assumes that p2dot = 0
  double f2dot = -2.*fdot*fdot/f;
  double delta = date - jbdate;
  double frq = f + delta * fdot + 0.5 * delta * delta * f2dot;
  double p = 1./frq;

  std::cout << "frequency2dot: " << f2dot << std::endl;

  std::cout << "Interpolated Crab frequency/period after " << delta
	    << " s:" << std::endl;
  std::cout << std::setprecision(15) << frq << " Hz" << std::endl;
  std::cout << p << " s" << std::endl;
}
 

  

  

